extensions [ nw matrix array]


;; defining the agents
breed [groups group ]
breed [ templates template ]


globals [landscape total-fitness avg-fitness time-used ]

;; defining attributes of group agents
groups-own [routine-list            ;; set of routines
            target-replicator-group ;; the target group from which to replicate routines
            target-routine-list     ;; the target set of routines to be replicated, namely, the routine list of target-replicator group
            group-neighbors         ;; neighbors of group agents defined by the group network
            replicate-flg?
            count-replicate-success  ;; number of successful replicating activity for group agents
            count-innovate-success  ;; number of successful innovating activity for group agents
            routine-network-matrix  ;; representing the random network relations between routines
            my-fitness ]

templates-own [ routine-list ]


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; SETUP procedure
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all



  ;; create the group agents on certain networks
  create-group-network

  ;; initialize landscape values
  ;;random-seed 1
  set landscape get-landscape number-of-routine-states k-routines-interacted
  print "This is the landscape matrix:"
  print matrix:pretty-print-text landscape
  print "-------------------------------------------------------"

  ;; initialize inputsetings and initial-states (including fitness values) of the group agents
  ask groups [
    initialize-group-agents-states
    set my-fitness ( update-fitness routine-list routine-network-matrix ) ]

  create-templates 1 [set hidden? true]
  show one-of templates

  set avg-fitness mean [my-fitness ] of groups
  set total-fitness avg-fitness
  reset-ticks
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; GO procedure
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  if ticks > stop-time [ stop ]

  if abs ( avg-fitness - ( mean [ my-fitness ] of groups ) ) > 0.00001 [

    set avg-fitness mean [ my-fitness ] of groups
    set time-used ticks
  ]

  ;; if is-env-change equals true, reset landscape values at given simulation ticks intervals.
  if is-env-change? [
    if ( (ticks - 1 ) mod env-change-P ) = 0 [
    ;;if random-float 1.0 < env-vary-probability [
      set landscape get-landscape number-of-routine-states k-routines-interacted
      show word "The environment variation occured at tick: ##" ticks ;; at the period: #" int ( ticks / env-vary-period )
      print "This is the landscape matrix:"
      print matrix:pretty-print-text landscape
      print "-------------------------------------------------------"

      ask groups [
        set my-fitness ( update-fitness routine-list routine-network-matrix )  ]
      set total-fitness total-fitness + mean [my-fitness ] of groups  ] ]


  ask one-of groups [
    ;; if certain conditions are satisfied, then the group agent select a target group as replicator,
    ;; and create a template agent in accordance with the its routines as the target to be replicated
    if is-replicate? [
      set target-replicator-group select-target-replicator-group
      if target-replicator-group != nobody [

      ;show word "the replicator group #" target-replicator-group
      ;ask link-with target-replicator-group  [ set color red ]

      ;; set target-routine-list [routine-list ] of target-replicator-group
      ; show [routine-list ] of target-replicator-group

      ;; create-tepmlate agent with its own routine-list duplicated from the replicator group agent
      ;; but with given probability of errors.
      create-template-routine-list ( [ routine-list ] of target-replicator-group )

      ;; copy routines from the template agent, limited by the replicatee's absorptive capability
      let routine-list-aa copy-routines-from-template

      ;; if innovation activity is permitted, call for the innovate-routine procedure
      if is-innovate? [
          if random-float 1.0 < innovate-succeed-probability [
            set routine-list-aa ( innovate-routines routine-list-aa ) ]
        ]

      let my-fitness-aa ( update-fitness routine-list-aa routine-network-matrix )

      ifelse my-fitness < my-fitness-aa [
        set routine-list routine-list-aa
        set my-fitness my-fitness-aa
      ]
        [ set my-fitness update-fitness routine-list routine-network-matrix ]

      ]
    ]
    set size ( 0.5 + my-fitness )
    ;; set color ( 95 + my-fitness * 5 )
  ]

  ;;avg-fitness mean [my-fitness ] of groups
  set total-fitness total-fitness + mean [my-fitness ] of groups

  tick
end


;; running the "go" procedure one tick, only using for program tests.
to go-once
  go

end

to-report innovate-routines [ r-list ]
  let routine-list-a r-list
  ;set count-innovate-success 0
  let jj random ( ( length routine-list-a ) - 1 )
  set routine-list-a (replace-item jj routine-list-a abs ( item jj routine-list-a - 1 ))
  ;show word "before innovation " r-list
  ;show word "after innovation " routine-list-a
  ;;let fit-b update-fitness r-list routine-network-matrix
  ;;let fit-a update-fitness routine-list-a routine-network-matrix
  ;;show word "fit-a " fit-a
  ;;show word "fit-b " fit-b
  ;;ifelse fit-a > fit-b [

    set count-innovate-success count-innovate-success + 1
    ;show word "innovate activity occured " routine-list-a
    report routine-list-a  ;;]
  ;;[ show word "no innovate activity occured" r-list
   ;; report r-list  ]
  ;  set count-innovate-success 0 ]

end


;; this procedure copy routines from the template agent, limited by the replicatee's absorptive capability
to-report copy-routines-from-template
  let temp-routine-list-1 routine-list
  let temp-routine-list-2 [routine-list ] of ( one-of templates )
  ;; set count-replicate-success 0
  ;show word "routinelist of replicatee" temp-routine-list-1
  ;show word "routinelist of template" temp-routine-list-2

  let rl-dist ( map [ [ a b ] -> (a != b ) ] temp-routine-list-1 temp-routine-list-2 )
  let ii 0
  let count-of-routine-changes 0
  foreach rl-dist [ ?1 ->
    if ?1 [
      ;;if random-float 1.0 < group-absorbe-capacity [
        set temp-routine-list-1 (replace-item ii temp-routine-list-1 ( item ii temp-routine-list-2 ))
        set count-of-routine-changes count-of-routine-changes + 1
      ;;]
    ]
    set ii ii + 1

    if count-of-routine-changes > 0 [
      set count-replicate-success count-replicate-success + 1 ]
    ;[ set count-replicate-success 0 ]

  ]
  ;show word "number of routines changed " count-of-routine-changes
  ;show word "routinelist of replicatee after copying" temp-routine-list-1

  report temp-routine-list-1
end

;; this procedure generates the template agent from the replicator group agent.
to create-template-routine-list [ r-list ]
  let r-list2 []
  ask one-of templates [
    set routine-list r-list
    let ii 0
    foreach r-list [?1 ->
      if random-float 1.0 < template-error-probability [
        set routine-list (replace-item ii routine-list abs (1 - ?1 ) )
      ]
      set ii ii + 1
    ]
    set r-list2 routine-list
  ]
  ;show word "the target-routine-list is :" r-list
  ;show word "the routine-list of template :" r-list2
  ;show word "the difference is " caculate-routine-distance r-list r-list2


end

to-report caculate-routine-distance [ r-list1 r-list2 ]
  ;; let r-distance sum ( map [ [ a b ] -> abs ( a - b ) ] r-list1 r-list2 )
  let r-distance ( map [ [ a b ] -> (a != b ) ] r-list1 r-list2 )

  let sum-rd 0
  foreach r-distance [ ?1 ->
    if ?1 [set sum-rd sum-rd + 1 ]
  ]
  report sum-rd
end

;; this procedure helps group agents to determine wether they need to replicate routines,
;; in accordance with their current fitness value
to-report is-replicate?
  let replicate-flg false

  if count group-neighbors > 0 [
    if my-fitness < mean [ my-fitness ] of group-neighbors [
      set replicate-flg true ]
  ]
  report replicate-flg
end


;; this procedure is of getting the target routines to be replicated
to-report select-target-replicator-group
  let target-group-list []
  let group-neighbor-list sort-on [ who ] group-neighbors

    foreach group-neighbor-list [ ?1 ->
    let rl-dist caculate-routine-distance ( [ routine-list ] of ?1 ) routine-list
    ;show word "rl distance " rl-dist
      ;if ( [my-fitness ] of ?1 > my-fitness ) and ( rl-dist > 0 ) and (rl-dist < 3 ) [
      if ( rl-dist > 0 ) and (rl-dist <= group-absorbe-capacity ) [
        set target-group-list lput ?1 target-group-list ]
    ]

  ifelse length target-group-list > 0 [
    report one-of target-group-list]
  [report nobody ]

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; this procedure initializes:
;; 1, the routine-list of each organization agents.
;; 2, randomly builds up the network of routines (the interactive relations between routines)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to initialize-group-agents-states

  ;; initialize count-replicate-success = 0, representing that no replicating activities occur.
  set count-replicate-success 0

  ;; randomly initialize the routine-list with random values [0, max-routine-states]
  set routine-list n-values number-of-routines [ random number-of-routine-states ]
  ; show word "routine-list is: " routine-list

  ;; randomly initialize routine-network structure, representing by a rotine-index-matrix
  let ii 0
  set routine-network-matrix[]
  repeat number-of-routines [
    ;; for each routine
    let routine-index-list []
    ;; the first element in the matrix is the routine itself.
    set routine-index-list fput ii routine-index-list
    ;; set routine-index-list lput 0 ii

    ;; randomly set k other routines as its neighbors
    repeat k-routines-interacted [
      let jj 0
      ;; these routines as neighbors should be different with eachother
      let temp-routine-index random number-of-routines
      while [member? temp-routine-index routine-index-list and jj < 50] [
        set temp-routine-index random number-of-routines
        set jj jj + 1
      ]
    set routine-index-list lput temp-routine-index routine-index-list
  ]
    ;; put the neighbors of each routine into the routine-network-matrix
    set routine-network-matrix lput routine-index-list routine-network-matrix
    set ii ii + 1
  ]

  ; show word "routine matrix is: " routine-network-matrix


end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; this procedure creates the landscape of the routine-network
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to-report get-landscape [ NN KK ]
  let DD NN ^ KK
  report matrix:from-row-list n-values NN [n-values DD [ random-float 1 ]]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; this procedure caculates and updates the fitness values of group agents
;; with a given routine-list (routine-network).
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to-report update-fitness [ r-list r-network ]
  let fitness 0
  let fit 0
  ;; let row-index 0
  ;; let col-index 0

  foreach r-network [ ?1 ->
    ;; show word "neighbors are " ?1
    let row-index item (item 0 ?1) r-list  ;; item (((length r-list) + ii + 1) mod (length r-list)) r-list
    ;; show word "this is row-index: " row-index

    ;; caculate the col-index value
    let col-index item (item 1 ?1) r-list
    let xx 0
    if length ?1 > 1 [
      repeat (length ?1 - 2 ) [
      set col-index (col-index * number-of-routine-states + item (item (xx + 2) ?1 ) r-list )
      set xx xx + 1
      ]
    ]
    ; show word "this is col-index: " col-index

    set fit fit + matrix:get landscape row-index col-index
    ; show word "this is fit: " fit
  ]

  set fitness fit / number-of-routines
   ; show word "my fitness is " fitness

  report fitness

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; this procedure creates group agents on networks
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to create-group-network
  if group-network-type = "ring" [create-regular-network ]
  if group-network-type  = "random" [ create-random-network ]
  if group-network-type = "small-world" [ create-SW-network ]
  ;;if group-network-type = "scale-free" [ create-SF-network ]

  ask groups [
    set shape "circle"
    set color blue
    ;;set size 0.8
    set size ( 0.5 + my-fitness * 5 )
    set group-neighbors link-neighbors
    ; show word "linked neighbors" group-neighbors
  ]

end

;; create a regular ring network
to create-regular-network
  nw:generate-ring groups links number-of-groups [ ]
end

;; create an Erdos-Renyi random network
to create-random-network
  nw:generate-random groups links number-of-groups random-connect-probability [ ]
end
;; create a watts-strogatz network
to create-SW-network
  nw:generate-watts-strogatz groups links number-of-groups neighborhood-size rewire-probability [ ]
end
;; create a preferential-attachment network
;;to create-SF-network
;;  nw:generate-preferential-attachment groups links number-of-groups [ ]
;;end

to layout
  layout-radial groups links group 0
  ;layout-spring groups links 0.5 10 1
  display
end
@#$#@#$#@
GRAPHICS-WINDOW
352
23
771
443
-1
-1
12.455
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
16
362
83
395
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
16
408
83
442
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
98
408
178
441
NIL
go-once
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
13
22
195
55
number-of-groups
number-of-groups
10
100
40.0
1
1
NIL
HORIZONTAL

CHOOSER
209
23
339
68
group-network-type
group-network-type
"ring" "random" "small-world" "scale-free"
1

SWITCH
198
365
326
398
is-innovate?
is-innovate?
0
1
-1000

SWITCH
198
409
326
442
is-env-change?
is-env-change?
0
1
-1000

SLIDER
13
277
198
310
innovate-succeed-probability
innovate-succeed-probability
0
1
0.6
0.1
1
NIL
HORIZONTAL

SLIDER
13
315
198
348
env-change-P
env-change-P
0
1000
1000.0
10
1
NIL
HORIZONTAL

SLIDER
13
233
198
266
group-absorbe-capacity
group-absorbe-capacity
0
8
2.0
1
1
NIL
HORIZONTAL

SLIDER
13
194
197
227
template-error-probability
template-error-probability
0
1
0.9
0.1
1
NIL
HORIZONTAL

BUTTON
98
362
177
397
NIL
layout
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
1081
265
1239
314
group-network-density
count links / ( count groups * ( count groups - 1 ) / 2)
5
1
12

MONITOR
1058
392
1142
441
time-used
time-used
5
1
12

MONITOR
1160
393
1259
442
avg-fitness
mean [my-fitness] of groups
5
1
12

SLIDER
13
148
197
181
k-routines-interacted
k-routines-interacted
0
number-of-routines - 1
7.0
1
1
NIL
HORIZONTAL

SLIDER
13
64
195
97
number-of-routines
number-of-routines
5
15
8.0
1
1
NIL
HORIZONTAL

SLIDER
13
105
196
138
number-of-routine-states
number-of-routine-states
2
5
2.0
1
1
NIL
HORIZONTAL

INPUTBOX
212
287
339
347
stop-time
3000.0
1
0
Number

PLOT
797
24
1255
246
plot-group-fitness
time
avg-fitness
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"avg-fit" 1.0 0 -14070903 true "" "plot mean [ my-fitness ] of groups"
"max-fit" 1.0 0 -7500403 true "" "plot max [my-fitness ] of groups"
"min-fit" 1.0 0 -2674135 true "" "plot min [ my-fitness ] of groups"

PLOT
797
266
1043
439
ratio-of-innov/replicat activities
count-replication
count-innovation
0.0
10.0
0.0
10.0
true
false
"set-plot-x-range 0 mean [count-replicate-success ] of groups + 3\nset-plot-y-range 0 mean [count-innovate-success ] of groups + 3" ""
PENS
"default" 500.0 2 -7858858 true "" "plotxy mean [ count-replicate-success ] of groups mean [ count-innovate-success ] of groups"

INPUTBOX
210
78
339
138
random-connect-probability
0.5
1
0
Number

INPUTBOX
211
148
339
208
neighborhood-size
4.0
1
0
Number

INPUTBOX
212
218
339
278
rewire-probability
0.1
1
0
Number

MONITOR
1081
326
1239
375
routine-network-density
k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )
17
1
12

@#$#@#$#@
## WHAT IS IT?

This is an agent-based model to explore routine replication dynamics considering two types of network contexts – namely, (1) connections between different (geographically distributed) units (which here we called “groups”) in a decentralized organization, and (2) the coupling relation between routines – i.e., a bundle of different routines involved in each group. 

## HOW IT WORKS

To do so, we first followed the NK and fitness landscape modelling to depict routine networks, and built up the fitness landscape of an organization. Then, we translated this into an agent-based model (ABM) to explore complex behaviors. 

We treated an aggregation of individuals and artifacts – namely, the unit distributed within an organization, which we called a ‘group’ – as the basic autonomous agent. All the groups (i.e., agents) randomly interacted with each other, while by using templates specific routines were replicated from group to group. Furthermore, we also considered the impact of both internal uncertainties and external dynamics of the organizational environment routine replications. This included, for example, template-duplicating errors and innovative activities among groups, and the pace of variation of the organizational environment.

We assumed that, firstly, group agents were prone to replicate ‘superior practices’ from neighbors only when they felt competitive pressures – i.e., they had a significantly lower fitness value than the average of neighbors. 

Next, a template was generated through explicitly codifying the knowledge embedded in the network of routines of the replicator group agent. Being templates a copy of the original series of routines, but allowing each of the element values of the vector tplk (0 ≤ k ≤ N) to vary with a certain probability of errors error_P (0 ≤ error_P ≤ 1). 

Furthermore, given that replicatee group agents were always constrained by a specific level of absorptive capacity, we assumed that they could not adopt the whole template but only a certain part. Here, we used a variable group_AC to represent the absorptive capacity of group agents. Its value numerically equaled the number of routines that replicatee group agents could change at a time according to the template, group_AC = {1, 2, 3}. Obviously, the higher the value of group_AC, the higher level of the group agent’s absorptive capacity was.

The replicatee group agents could randomly select a number of routines (which numerically equaled the group_AC value), which owned different states with those from the template – if they were existed, of course. Then, the replicatee group agents changed the relating routines’ states (values) according to the template, and generated a new list of routines R’.

Finally, when the new collection of routines R’ was formed, replicatee group agents checked if they could perform any innovation to match their work of routines (obviously, here, referring to the list of routines R’) and the specific context in which they were living. This was to mimic the ‘context-dependent’ characteristic of organizational routines as well as the interconnection between routines. For example, replicatee groups could revise parts of the network of routines while considering both the embeddedness of the systems of routines and certain fitness landscapes – namely, the living environment of the groups. By doing these innovation activities, replicatee group agents transformed the temporary list of routines R’ into their final network of routines R with newly updated status.

In addition, we assumed that replicatee group agents could innovate and randomly change the state of one of their routines with a given probability innovate_p (0 ≤ innovate_p ≤ 1) – when this was helpful to improve their fitness values.


## HOW TO USE IT

The SETUP button creates group agents with a random set of routines. Once the simulation has been setup, you are now ready to run it, by pushing the GO button. GO starts the simulation and runs it continuously until GO is pushed again. Or you can push GO-ONCE button to run the simulation step-by-step. During a simulation initiated by GO or GO-ONCE, adjustments in sliders can affect the behavioral tendencies of the population.
A monitor shows replicating dynamics of routines between different group agents. In this model each time-step is considered one iteration of the routine replication activities.

Here is a summary of the sliders in the model:
num-of-groups: The number of group agents involved in the organization;
num-of-routines: The number of routines involved in each group agent;
num-of-routine-states: The number of states for every routine
k-routine-related: The number of routines that affect one certain routine’s contribution to the group’s fitness, (1 =< k-routine-related =< number-of-routines - 1);
template-error-probability: The probability of errors occurring when replicatee groups duplicated routines from a template;
group-absorbe-capacity: Absorptive capacity of each group agent
innovate-succeed-probability: The probability of innovative activities for each group agent;
env-vary-period: The simulation rounds period of environmental variations;
group-network-type: In this model, we choose the E-R random model.
random-connect-probability: A parameter used in the E-R random network model, representing the connecting probability between nodes;
neighborhood-size: A parameter used in the SW network model;
rewire-probability: A parameter used in the SW network model;
stop-time: Total simulation rounds for running of the simulation each time;
is-innovate?: A Boolean variable representing whether innovation activities is allowed or not;
is-env-vary?: A Boolean variable representing whether the environmental variations is existed or not;

Four monitors provide the outputs including density of both group and routine networks, simulation rounds used for the routine system to arrive at a stable state, and the average fitness of the organization, respectively.

The model’s plots show the total number of group agents involved in both replicating and innovating activities, the average-fitness values of the organization, and the ratio of the number of group agents involved in replicating-innovative activities.

## THINGS TO NOTICE

In order to reduce the impact of statistical factors involved in our model, we repeated running of the simulation 800 times for every different scenario, and kept each running lasting for at least 3000 rounds – here, each round representing one performance of the routine – to ensure that the organization system reached a steady status, if it eventually existed.

## THINGS TO TRY

A comparision between four different group network models can be done by varing the parameter group-network-type values.

## CREDITS AND REFERENCES

Please cite this model as the following:

Dehua Gao, Flaminio Squazzoni, Xiuquan Deng (2018). The intertwining impact of intra-organizational and routine networks on routine replication dynamics: An agent-based model, Shandong Technology and Business University, Working paper
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="is-innovate?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-groups">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-period">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="300" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-period">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="2500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-period">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="600" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="20"/>
      <value value="40"/>
      <value value="60"/>
      <value value="80"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-change-P">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-change?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="800" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-period">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="800" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-period">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="800" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-period">
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="300" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-period">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="2500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="800" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-period">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0.05"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0.05"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="300" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>total-fitness / ticks</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-vary-period">
      <value value="100"/>
      <value value="400"/>
      <value value="800"/>
      <value value="1200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-vary?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experimentRA1" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-change-P">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-change?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experimentRA2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-change-P">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-change?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experimentRA3" repetitions="260" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-change-P">
      <value value="200"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-change?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experimentRA4" repetitions="260" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count links / ( count groups * ( count groups - 1 ) / 2)</metric>
    <metric>k-routines-interacted * number-of-routines / (number-of-routines * (number-of-routines - 1 ) / 2 )</metric>
    <metric>mean [ count-replicate-success ] of groups</metric>
    <metric>mean [count-innovate-success ] of groups</metric>
    <metric>time-used</metric>
    <metric>avg-fitness</metric>
    <enumeratedValueSet variable="number-of-groups">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-network-type">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-routines-interacted">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewire-probability">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="env-change-P">
      <value value="200"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routine-states">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="random-connect-probability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-innovate?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-routines">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neighborhood-size">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-time">
      <value value="3000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="group-absorbe-capacity">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="template-error-probability">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovate-succeed-probability">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="is-env-change?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
